# Release Notes

```eval_rst
.. todo::

    - Bring these release notes up-to-date
```

**2020-09-30**

- New Scalable architecture and new website, running on cloud resources

**2020-04-09**

- Release of Sherlock 2.0

**2020-04-07**

- Added [Lasair Cookbook](https://lsst-uk.atlassian.net/l/c/1S1VEAAo) to documentation

**2020-04-04**

- Added Sherlock documentation

**2019-12-23**

- Active queries can produce email alerts to the users

**2019-12-23**

- Active queries can produce Kafka streams

**2019-12-23**

- Queries can now be made active so they run in the night as data comes in

**2019-10-28**

- Object table now includes `_ncandgp_`, the number of good and positive candidates

**2019-10-28**

- Autocomplete now available as part of the query/filter mechanism

**2019-10-28**

- Watchlists now available as part of the query/filter mechanism

**2019-10-28**

- Watchlists can now have non-uniform radius

**2019-08-18**

- Addition of new machine-learning real-bogus classifier

**2019-08-18**

- Output streams from active queries

**2019-08-18**

- Addition of 6 moving averages of apparent magnitude to detect outburst


**2019-07-19**

- Addition of computed apparent magnitude to candidate table

**2019-06-10**

- All queries fit with streaming model

**2019-02-07**

- Release of beta website

**2019-01-26**

- LIGO-Virgo Skymaps

**2018-12-20**

- Automated crossmatch with TNS

**2018-12-07**

- Comments on objects, searchable

**2018-11-19**

- Queries can be stored with a user, made public or not

**2018-11-19**

- Cone search now takes a single string

**2018-11-10**

- Support for solar system objects

**2018-11-10**

- Support for nondetections of objects with magnitude limit

**2018-11-10**

- Support for galactic longitude and latitude

**2018-11-10**

- Freeform SQL queries on three tables: Objects, Candidates, and Sherlock\_crossmatches

**2018-09-13**

- First implementation of watchlists

**2018-09-13**

- Cone Search

**2018-07-13**

- Sortable tables

**2018-07-10**

- Added sortable table to object and coverage pages

**2018-07-06**

- Added plots for light curves and dartboard plot

**2018-06-28**

- Added coverage visualisation

**2018-06-27**

- Website running

